# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# TODO: BR:/R: perl(Archive::Unzip::Burst) when available

Name:		perl-PAR-Dist
Version:	0.52
Release:	1.%{__distinit}%{__distvers}
Summary:	Toolkit for creating and manipulating Perl PAR distributions
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/PAR-Dist
Source0:	https://cpan.metacpan.org/authors/id/R/RS/RSCHUPP/PAR-Dist-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
# Module Runtime
BuildRequires:	perl(Archive::Zip)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Config)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(ExtUtils::Install)
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(ExtUtils::MY)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(LWP::Simple)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
BuildRequires:	perl(YAML::XS)
# Test Suite
BuildRequires:	perl(Test)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(warnings)
# Optional Tests
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.00
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Archive::Zip)
Requires:	perl(Config)
Requires:	perl(Cwd)
Requires:	perl(ExtUtils::Install)
Requires:	perl(ExtUtils::MakeMaker)
Requires:	perl(ExtUtils::MY)
Requires:	perl(File::Copy)
Requires:	perl(File::Find)
Requires:	perl(File::Path)
Requires:	perl(File::Temp)
Requires:	perl(LWP::Simple)
Requires:	perl(YAML::XS)

# Module::Signature requires PAR::Dist
%if !0%{?perl_bootstrap:1}
BuildRequires:	perl(Module::Signature)
Requires:	perl(Module::Signature)
%endif

%description
This module creates and manipulates PAR distributions. They are architecture-
specific PAR files, containing everything under blib/ of CPAN distributions
after their make or Build stage, a META.yml describing metadata of the
original CPAN distribution, and a MANIFEST detailing all files within it.
Digitally signed PAR distributions will also contain a SIGNATURE file.

%prep
%setup -q -n PAR-Dist-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test PERL_TEST_POD=1

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/PAR/
%{_mandir}/man3/PAR::Dist.3*

%changelog
* Sun May  7 2023 Paul Howarth <paul@city-fan.org> - 0.52-1
- Update to 0.52
  - Change bug tracker to GitHub issues
  - Quote all version numbers in META.yml files in test *.par files
- Use SPDX-format license tag
- Use %%license unconditionally

* Tue Dec  1 2020 Paul Howarth <paul@city-fan.org> - 0.51-1
- Update to 0.51
  - Fix problem with Cwd::realpath(): some versions of Cwd::realpath() must be
    called on an *existing* path, otherwise they will return undef

* Wed Nov 18 2020 Paul Howarth <paul@city-fan.org> - 0.50-1
- Update to 0.50
  - Fix for Archive::Zip related test failures due to symlinks (CPAN RT#132067)
  - Create repo on GitHub, update metadata
- Switch upstream from search.cpan,org to metacpan.org
- Package new LICENSE file

* Thu Apr 19 2018 Paul Howarth <paul@city-fan.org> - 0.49-14
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Thu Sep 15 2016 Paul Howarth <paul@city-fan.org> - 0.49-10
- Classify buildreqs by usage
- Simplify find command using -delete

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 0.49-6
- Drop %%defattr, redundant since rpm 4.4

* Mon Oct 15 2012 Paul Howarth <paul@city-fan.org> - 0.49-1
- Update to 0.49
  - PAR::Dist::parse_dist_name mis-parsed par file name (CPAN RT78194)
- This release by RSCHUPP -> update source URL

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 0.48-3
- Perl 5.16 post-bootstrap rebuild

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> - 0.48-2
- BR:/R: perl(Cwd), perl(ExtUtils::Install), perl(ExtUtils::MY),
  perl(File::Path), perl(File::Temp), perl(LWP::Simple) and
  perl(Module::Signature) 
- Don't BR: perl(Module::Signature) if we're bootstrapping
- BR: perl(Carp), perl(Exporter), perl(File::Spec) and perl(Test)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Always BR:/R: perl(YAML::XS)
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Sat Nov  5 2011 Paul Howarth <paul@city-fan.org> - 0.48-1
- Update to 0.48
  - Prefer MYMETA.yml over META.yml if possible
  - Try YAML implementations in different order (XS first)
- BR: perl(YAML::XS) rather than perl(YAML) if we have perl 5.8.5 or later
- Add runtime dependency on our preferred YAML implementation

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 0.47-4
- Rebuild for perl 5.14.1 in Rawhide
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.47-3
- Rebuild for perl 5.12.1 in Rawhide

* Wed Jun  2 2010 Paul Howarth <paul@city-fan.org> - 0.47-2
- Fix dist tag for RHEL-6 Beta

* Sun Nov 29 2009 Paul Howarth <paul@city-fan.org> - 0.47-1
- Update to 0.47 (POD fixes)
- Dist tag for Rawhide no longer needs special-casing

* Mon Aug  3 2009 Paul Howarth <paul@city-fan.org> - 0.46-1
- Update to 0.46 (do not use Archive::Zip if its version is 1.28)
- Add perl(Archive::Zip) as buildreq and req

* Mon Jun 15 2009 Paul Howarth <paul@city-fan.org> - 0.45-1
- Update to 0.45 (fix test skipping if optional dependencies can't be found)

* Mon Feb  2 2009 Paul Howarth <paul@city-fan.org> - 0.44-1
- Update to 0.44
  - Abandon support for perl 5.005
  - Merging of the various requires-like META.yml sections in merge_par

* Sat Jan 24 2009 Paul Howarth <paul@city-fan.org> - 0.43-1
- Update to 0.43 (don't trust return value of ExtUtils::Install::(un)?install)

* Thu Jan 22 2009 Paul Howarth <paul@city-fan.org> - 0.42-1
- Update to 0.42 (application of patch from 0.41 done properly)

* Fri Dec 19 2008 Paul Howarth <paul@city-fan.org> - 0.41-1
- Update to 0.41 (patch for blib_to_par across filesystem boundaries)

* Thu Oct 30 2008 Paul Howarth <paul@city-fan.org> - 0.40-1
- Import from Fedora
- Update to 0.40
- Add buildreqs perl(YAML), zip, unzip for test suite

* Thu Sep 25 2008 Marcela Maslanova <mmaslano@redhat.com> - 0.34-2
- Forgot apply source

* Thu Sep 25 2008 Marcela Maslanova <mmaslano@redhat.com> - 0.34-1
- Update to 0.34 → it was needed for perl-PAR

* Sat May 31 2008 Steven Pritchard <steve@kspei.com> - 0.31-1
- Update to 0.31
- BR Test::Pod and Test::Pod::Coverage

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.29-2
- Rebuild for perl 5.10 (again)

* Thu Feb 21 2008 Steven Pritchard <steve@kspei.com> - 0.29-1
- Update to 0.29
- Use fixperms macro instead of our own chmod incantation
- Reformat to match cpanspec output

* Thu Jan 10 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.25-4
- Rebuild (again) for new perl

* Thu Jan 10 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.25-3
- Rebuild for new perl

* Mon Aug  6 2007 Ville Skyttä <ville.skytta at iki.fi> - 0.25-2
- License: GPL+ or Artistic

* Mon Jul 30 2007 Ville Skyttä <ville.skytta at iki.fi> - 0.25-1
- 0.25

* Sun Jul 22 2007 Ville Skyttä <ville.skytta at iki.fi> - 0.24-1
- 0.24

* Mon Jun 25 2007 Ville Skyttä <ville.skytta at iki.fi> - 0.23-1
- 0.23

* Sun May  6 2007 Ville Skyttä <ville.skytta at iki.fi> - 0.22-1
- 0.22

* Tue Apr 17 2007 Ville Skyttä <ville.skytta at iki.fi> - 0.21-2
- BuildRequire perl(ExtUtils::MakeMaker) and perl(Test::More)

* Sun Oct 15 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.21-1
- 0.21

* Thu Oct 12 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.20-1
- 0.20

* Sun Sep 17 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.19-1
- 0.19

* Mon Aug 28 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.18-1
- 0.18

* Tue Aug 15 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.16-1
- 0.16

* Sat Jul 29 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.15-1
- 0.15

* Sun Jul 23 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.14-1
- 0.14

* Thu Jul 20 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.11-1
- 0.11
- Fix order of options to find(1) in %%install

* Thu Jun  8 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.10-1
- 0.10

* Fri Feb 24 2006 Ville Skyttä <ville.skytta at iki.fi> - 0.08-1
- 0.08
- Specfile cleanups

* Thu Mar 17 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.07-3
- Avoid running signature test during build
- Sync with fedora-rpmdevtools' Perl spec template

* Sun Apr 25 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.07-0.fdr.2
- Require perl(:MODULE_COMPAT_*)

* Sat Mar 27 2004 Ville Skyttä <ville.skytta at iki.fi> - 0:0.07-0.fdr.1
- First build
